# Temerity

***Kotlin Multiplatform Library for interacting with the YuJa Enterprise Video Platform***

[![Maven Local](https://img.shields.io/maven-metadata/v?metadataUrl=https%3A%2F%2Fgit.ucsc.edu%2Fapi%2Fv4%2Fprojects%2F12162%2Fpackages%2Fmaven%2Fedu%2Fucsc%2Fits%2Ftemerity%2Fmaven-metadata.xml)](https://git.ucsc.edu/wnwalker/temerity/-/packages)
[![Pipeline](https://git.ucsc.edu/wnwalker/temerity/badges/main/pipeline.svg)](https://git.ucsc.edu/wnwalker/temerity/-/pipelines)
[![Issues](https://img.shields.io/gitlab/issues/open/wnwalker%2Ftemerity?gitlab_url=https%3A%2F%2Fgit.ucsc.edu)](https://git.ucsc.edu/wnwalker/temerity/-/issues)
[![Kotlin](https://img.shields.io/badge/kotlin-2.0.20-blue?logo=kotlin)](http://kotlinlang.org)
[![Gradle](https://img.shields.io/badge/Gradle-8-green?style=flat)](https://gradle.org)
[![License](https://img.shields.io/badge/license-GNU%20LGPL%202.1-blue.svg?style=flat)](https://www.gnu.org/licenses/old-licenses/lgpl-2.1.en.html)

## How to add and use this library

The library is available from the public Maven repository for this Gitlab project.

### Dependency setup instructions

Add the Maven repository if it is not already present, either in your build.gradle.kts file or in a `dependencyResolutionManagement{}` block in your settings.gradle.kts file.

```kotlin
repositories {
  maven("https://git.ucsc.edu/api/v4/projects/12162/packages/maven")
}
```

To use the library in a regular JVM project, add a dependency.

```kotlin
dependencies {
  implementation("edu.ucsc.its:temerity-jvm:0.1.0")
}
```

In Kotlin Multiplatform projects, add the dependency to the commonMain source-set.

```kotlin
commonMain {
    dependencies { 
      implementation("edu.ucsc.its:temerity:0.1.0")
    }
}
```

### Usage 

Build a Temerity client, then start making requests:

```kotlin
    val client = Temerity {
                serviceUrl("https://your_organization.yuja.com/services/")
                serviceToken("your_API_token") }
    runBlocking { client.getUsers().forEach { println(it) } }

    val returnedDevices = runBlocking { client.getDevices() }
    println("Returned devices:")
    returnedDevices.forEach { println(it) }

    stopTemerity()
```

## Result:

```kotlin
User(loginId=...., emailAddress=...., userType=Student, userId=12345678, timezone=America/Los_Angeles, customId=, lastName=...,
User(...)
User(...)

// Returned devices:
Device(stationName=DELL-DATAPATH-9020, accessLevel=Administrators, deviceId=...
Device(stationName=DELL-DATAPATH-7040, accessLevel=Administrators, deviceId=...
Device(...
Device(...
```